@@ -15,6 +15,10 @@ def to_snake(value: str) -> str:
     words = re.findall(r'([A-Z]?[^_\-\sA-Z]+)', value)
     return '_'.join(map(lambda x: x.lower(), words))
 
+def to_kebab(value: str) -> str:
+    pass
+    #words = re.findall(r()
+
 
 def to_base64(value: str):
     encoded_value = base64.urlsafe_b64encode(value.encode('utf-8'))
